==> mx-menu-editor_19.5.tar.xz: mx-menu-editor-19.5/translations/mx-menu-editor_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Tilføj kategori</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Slet kategori</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Gem ændringer</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Afslut dialog</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Indstil ikon</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Opstartsnotifikator</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Tilføj tilpasset program</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Kunne ikke gemme filen</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Gem ændringer?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Vil du gemme dine redigeringer?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>MX Menu Editor</source>
        <translation>MX Menuredigering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Avanceret editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorier og programmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Tilføj tilpasset program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Notifikation om opstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Hurtig editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Gendan originale punkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Change icon</source>
        <translation>Skift ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Katogorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Gem ændringer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Select executable file</source>
        <translation>Vælg eksekverbar fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Billedfiler (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Choose category</source>
        <translation>Vælg kategori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="845"/>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Could not save the file</source>
        <translation>Kunne ikke gemme filen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>About MX Menu Editor</source>
        <translation>Om MX Menuredigering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Program for editing Xfce menu</source>
        <translation>Program til at redigere Xfce-menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save changes?</source>
        <translation>Gem ændringer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Do you want to save your edits?</source>
        <translation>Vil du gemme dine redigeringer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Du skal køre programmet som normal bruger.</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_21.7.01.tar.xz: mx-menu-editor-21.7.01/translations/mx-menu-editor_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Tilføj kategori</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Slet kategori</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Gem ændringer</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Afslut dialog</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Vælg...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="111"/>
        <source>Set icon</source>
        <translation>Indstil ikon</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Opstartsunderretter</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="35"/>
        <source>Add Custom Application</source>
        <translation>Tilføj tilpasset program</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Could not save the file</source>
        <translation>Kunne ikke gemme filen</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Save changes?</source>
        <translation>Gem ændringer?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Do you want to save your edits?</source>
        <translation>Vil du gemme dine redigeringer?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Gem</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>MX Menu Editor</source>
        <translation>MX Menuredigering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Avanceret editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorier og programmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Tilføj tilpasset program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Underret om opstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Hurtig editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Gendan originale punkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Vælg...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Change icon</source>
        <translation>Skift ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Katogorier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Gem ændringer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Select executable file</source>
        <translation>Vælg eksekverbar fil</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation type="vanished">Billedfiler (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Choose category</source>
        <translation>Vælg kategori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Could not save the file</source>
        <translation>Kunne ikke gemme filen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>About MX Menu Editor</source>
        <translation>Om MX Menuredigering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Program for editing Xfce menu</source>
        <translation>Program til at redigere Xfce-menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>Save changes?</source>
        <translation>Gem ændringer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Do you want to save your edits?</source>
        <translation>Vil du gemme dine redigeringer?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Du skal køre programmet som normal bruger.</translation>
    </message>
</context>
</TS>
